;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "leuven-theme" "20250917.1957"
  "Elegant Emacs color theme for a white background."
  ()
  :url "https://github.com/fniessen/emacs-leuven-theme"
  :commit "802f5593b83c680bd5152d3b3f98ca184eb481a7"
  :revdesc "802f5593b83c"
  :keywords '("color" "theme")
  :authors '(("Fabrice Niessen" . ""))
  :maintainers '(("Fabrice Niessen" . "")))
